@@ -38,10 +38,10 @@ emacspeak modules:
 
 """
 
-__id__ = "$Id: espeechfactory.py,v 1.12 2006/10/06 07:59:03 richb Exp $"
-__author__ = "$Author: richb $"
-__version__ = "$Revision: 1.12 $"
-__date__ = "$Date: 2006/10/06 07:59:03 $"
+__id__ = "$Id: espeechfactory.py 1680 2006-11-09 18:43:48Z wwalker $"
+__author__ = "T. V. Raman"
+__version__ = "$Revision: 1680 $"
+__date__ = "$Date: 2006-11-09 13:43:48 -0500 (Thu, 09 Nov 2006) $"
 __copyright__ = "Copyright (c) 2005 Google Inc."
 __license__ = "LGPL"
 __all__=['Speaker']
