@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py,v 1.87 2006/12/03 11:24:21 wwalker Exp $"
-__version__   = "$Revision: 1.87 $"
-__date__      = "$Date: 2006/12/03 11:24:21 $"
+__id__        = "$Id: speechgenerator.py 1965 2007-01-31 01:39:25Z wwalker $"
+__version__   = "$Revision: 1965 $"
+__date__      = "$Date: 2007-01-30 20:39:25 -0500 (Tue, 30 Jan 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -812,7 +812,8 @@ class SpeechGenerator:
         if len(utterances) == 0:
             if obj.name and (len(obj.name)):
                 utterances.append(obj.name)
-        utterances.extend(self._getSpeechForObjectRole(obj))
+        if obj.role != rolenames.ROLE_PARAGRAPH:
+            utterances.extend(self._getSpeechForObjectRole(obj))
 
         [text, caretOffset, startOffset] = util.getTextLineAtCaret(obj)
         utterances.append(text)
@@ -1065,7 +1066,7 @@ class SpeechGenerator:
         try:
             minimumIncrement = value.minimumIncrement
         except:
-            pass
+            minimumIncrement = 0.0
 
         if minimumIncrement == 0.0:
             minimumIncrement = (value.maximumValue - value.minimumValue) \
@@ -1258,7 +1259,8 @@ class SpeechGenerator:
         utterances = []
 
         if (not already_focused):
-            if settings.readTableCellRow:
+            if settings.readTableCellRow and obj.parent.table \
+                and (not self._script.isLayoutOnly(obj.parent)):
                 parent = obj.parent
                 row = parent.table.getRowAtIndex(obj.index)
                 column = parent.table.getColumnAtIndex(obj.index)
@@ -1292,6 +1294,11 @@ class SpeechGenerator:
         else:
             utterances = self._getSpeechForTableCell(obj, already_focused)
 
+        self._debugGenerator("_getSpeechForTableCellRow",
+                             obj,
+                             already_focused,
+                             utterances)
+
         return utterances
 
     def _getSpeechForTableColumnHeader(self, obj, already_focused):
@@ -1560,20 +1567,17 @@ class SpeechGenerator:
                 and (parent.role != rolenames.ROLE_LAYERED_PANE) \
                 and (parent.role != rolenames.ROLE_SPLIT_PANE) \
                 and (parent.role != rolenames.ROLE_SCROLL_PANE) \
-                and (parent.role != rolenames.ROLE_UNKNOWN):
+                and (parent.role != rolenames.ROLE_UNKNOWN) \
+                and (not self._script.isLayoutOnly(parent)):
 
                 # Announce the label and text of the object in the hierarchy.
                 #
                 text = util.getDisplayedText(parent)
                 label = util.getDisplayedLabel(parent)
 
-                # Don't announce unlabelled panels.
+                # Push announcement of cell after text and label.
                 #
-                if parent.role == rolenames.ROLE_PANEL \
-                   and (((not label) or (len(label) == 0) \
-                         or (not text) or (len(text) == 0))):
-                    pass
-                elif parent.role != rolenames.ROLE_TABLE_CELL:
+                if parent.role != rolenames.ROLE_TABLE_CELL:
                     utterances.append(rolenames.getSpeechForRoleName(parent))
 
                 if text and len(text):
